@@ -13,31 +13,41 @@
 #' @examples
 #' brain_pal("dk")
 #' brain_pal("aseg")
-brain_pal <- function(name, n="all", direction=1, unname=FALSE,
-                      package="ggseg"){
-
+brain_pal <- function(
+  name,
+  n = "all",
+  direction = 1,
+  unname = FALSE,
+  package = "ggseg"
+) {
   brain_pals <- get_pals(package)
 
   info <- brain_pals_info(package = package)
 
-  if(!(name %in% info$atlas)){
-    stop(paste(name,"is not a valid palette name for brain_pal\n"))
+  if (!(name %in% info$atlas)) {
+    stop(paste(name, "is not a valid palette name for brain_pal\n"))
   }
 
-  if(length(n)>1){
+  if (length(n) > 1) {
     n = n
-  }else if(n == "all"){
-    n = seq(1,info[info$atlas %in% name,"maxcol"])
-  }else if(n < 3){
-    warning("minimal value for n is 3, returning requested palette with 3 different levels\n")
+  } else if (n == "all") {
+    n = seq(1, info[info$atlas %in% name, "maxcol"])
+  } else if (n < 3) {
+    warning(
+      "minimal value for n is 3, returning requested palette with 3 different levels\n"
+    )
     n = seq(1:3)
-  }else if(n > info[info$atlas %in% name,"maxcol"]){
-    warning(paste("n too large, allowed maximum for palette",name,"is",
-                  info[info$atlas %in% name,"maxcol"],
-                  "\nReturning the palette you asked for with that many colors\n"))
-    n = seq(1,info[info$atlas %in% name,"maxcol"])
-  }else{
-    n = seq(1,n)
+  } else if (n > info[info$atlas %in% name, "maxcol"]) {
+    warning(paste(
+      "n too large, allowed maximum for palette",
+      name,
+      "is",
+      info[info$atlas %in% name, "maxcol"],
+      "\nReturning the palette you asked for with that many colors\n"
+    ))
+    n = seq(1, info[info$atlas %in% name, "maxcol"])
+  } else {
+    n = seq(1, n)
   }
 
   pal = brain_pals[[name]]
@@ -46,7 +56,7 @@ brain_pal <- function(name, n="all", direction=1, unname=FALSE,
     pal <- rev(pal)
   }
 
-  if(unname){
+  if (unname) {
     pal = unname(pal)
   }
 
@@ -61,16 +71,16 @@ brain_pal <- function(name, n="all", direction=1, unname=FALSE,
 #'
 #' @examples
 #' brain_pals_info()
-brain_pals_info <- function(package="ggseg"){
-
+brain_pals_info <- function(package = "ggseg") {
   brain_pals <- get_pals(package)
 
   data.frame(
-    atlas=names(unlist(lapply(brain_pals,length))),
-    maxcol=unname(unlist(lapply(brain_pals,length))),
-    category="qual",
-    colorblind=FALSE,
-    stringsAsFactors = FALSE)
+    atlas = names(unlist(lapply(brain_pals, length))),
+    maxcol = unname(unlist(lapply(brain_pals, length))),
+    category = "qual",
+    colorblind = FALSE,
+    stringsAsFactors = FALSE
+  )
 }
 
 
@@ -82,11 +92,12 @@ brain_pals_info <- function(package="ggseg"){
 #' @inheritParams brain_pal
 #' @keywords internal
 #' @noRd
-get_colours <- function(name, n, unname, package){
-  data.frame(atlas = name,
-             colour = brain_pal(name=name, n=n, unname=unname,
-                                package = package),
-             stringsAsFactors = FALSE)
+get_colours <- function(name, n, unname, package) {
+  data.frame(
+    atlas = name,
+    colour = brain_pal(name = name, n = n, unname = unname, package = package),
+    stringsAsFactors = FALSE
+  )
 }
 
 #' Get brain palettes
@@ -99,11 +110,11 @@ get_colours <- function(name, n, unname, package){
 #' @inheritParams brain_pal
 #' @keywords internal
 #' @noRd
-get_pals <- function(package = "ggseg"){
-  eval(parse(text=paste(package, "brain_pals", sep=":::")))
+get_pals <- function(package = "ggseg") {
+  eval(parse(text = paste(package, "brain_pals", sep = ":::")))
 }
 
 ## quiets concerns of R CMD check
-if(getRversion() >= "2.15.1"){
-  utils::globalVariables(c("info","brain_pals"))
+if (getRversion() >= "2.15.1") {
+  utils::globalVariables(c("info", "brain_pals"))
 }
